@@ -2,11 +2,11 @@
 
 #pragma once
 
-#include "Tag.h"
-#include "plugin/Component.h"
-#include "plugin/TaggedComponent.h"
+#include "zeek/Tag.h"
+#include "zeek/plugin/Component.h"
 
-namespace input {
+namespace zeek::input
+	{
 
 class ReaderFrontend;
 class ReaderBackend;
@@ -14,10 +14,10 @@ class ReaderBackend;
 /**
  * Component description for plugins providing log readers.
  */
-class Component : public plugin::Component,
-		  public plugin::TaggedComponent<input::Tag> {
+class Component : public plugin::Component
+	{
 public:
-	typedef ReaderBackend* (*factory_callback)(ReaderFrontend* frontend);
+	using factory_callback = ReaderBackend* (*)(ReaderFrontend* frontend);
 
 	/**
 	 * Constructor.
@@ -48,16 +48,16 @@ public:
 	/**
 	 * Returns the reader's factory function.
 	 */
-	factory_callback Factory() const	{ return factory; }
+	factory_callback Factory() const { return factory; }
 
 protected:
 	/**
-	  * Overriden from plugin::Component.
-	  */
+	 * Overriden from plugin::Component.
+	 */
 	void DoDescribe(ODesc* d) const override;
 
 private:
 	factory_callback factory;
-};
+	};
 
-}
+	} // namespace zeek::input
