@@ -6,23 +6,22 @@
 
 #include <functional>
 
-#include "zeek/util.h"
-#include "zeek/packet_analysis/Tag.h"
-
+#include "zeek/Tag.h"
 #include "zeek/plugin/Component.h"
-#include "zeek/plugin/TaggedComponent.h"
+#include "zeek/util.h"
 
-namespace zeek::packet_analysis {
+namespace zeek::packet_analysis
+	{
 
 class Analyzer;
 using AnalyzerPtr = std::shared_ptr<Analyzer>;
 
-class Component : public plugin::Component,
-                  public plugin::TaggedComponent<packet_analysis::Tag> {
+class Component : public plugin::Component
+	{
 public:
-	using factory_callback = std::function<AnalyzerPtr ()>;
+	using factory_callback = std::function<AnalyzerPtr()>;
 
-	Component(const std::string& name, factory_callback factory, Tag::subtype_t subtype = 0);
+	Component(const std::string& name, factory_callback factory, zeek::Tag::subtype_t subtype = 0);
 	~Component() override = default;
 
 	/**
@@ -45,6 +44,6 @@ protected:
 
 private:
 	factory_callback factory; // The analyzer's factory callback.
-};
+	};
 
-}
+	}
